pub struct RStudentFilePolicy { /* private fields */ }Trait Implementations
Sourceimpl StudentFilePolicy for RStudentFilePolicy
impl StudentFilePolicy for RStudentFilePolicy
Sourcefn new_with_project_config(project_config: TmcProjectYml) -> Selfwhere
Self: Sized,
fn new_with_project_config(project_config: TmcProjectYml) -> Selfwhere
Self: Sized,
This constructor should store the project config in the implementing struct.
Sourcefn get_project_config(&self) -> &TmcProjectYml
fn get_project_config(&self) -> &TmcProjectYml
The policy should contain a TmcProjectYml parsed from the project this policy was created for.
Sourcefn is_non_extra_student_file(&self, path: &Path) -> bool
fn is_non_extra_student_file(&self, path: &Path) -> bool
Used by is_student_file.
Defines a language plugin policy’s rules for determining whether a file is a student file or not.
Sourcefn new(project_dir: &Path) -> Result<Self, TmcError>where
Self: Sized,
fn new(project_dir: &Path) -> Result<Self, TmcError>where
Self: Sized,
Parses a project config and calls the helper constructor. Implementing types should only be constructed using this function.